pub enum AudioCodec {
LPcm,
}Expand description
Enumeration of all the audio codecs, allows static dispatch on decoding rather than using a trait object
Variants
LPcm
The Linear Pulse-Code Modulation encoding. Often refered to as just PCM.