Samples

Struct Samples 

pub struct Samples<T: Sample> {
    pub samples: Vec<T>,
    pub metadata: SamplesMetadata,
}
A sample container of LPcm samples ready to be send to audio streams

Fields

samples: Vec<T>

A an ordered vector of all the samples, if there are multiple channels, each channel will have their own sample

ex: 1 channel: [s1, s2, s3]

2 channels: [s-left1, s-right1, s-left-2, s-right-2, s-left-3, s-right-3]

metadata: SamplesMetadata

The metadata of the Samples, dictates how they are consumed and modified. There is no guarenty that the metadata reflects the actual intended metadata.

Implementations

Source

impl<T: Sample> Samples<T>

pub fn new(samples: Vec<T>, metadata: SamplesMetadata) -> Samples<T>

Creates a new Samples struct

Source

impl Samples<IntermediateSampleType>

pub fn into_t_samples<T: Sample + FromSample<IntermediateSampleType>>( self, ) -> Samples<T>

Turns the samples into the desired sample type, does not clone