Shittify

Struct Shittify 

pub struct Shittify;
It’s quite the crude name, I think you can guess what it does. Artificially flattens the audio, reduces the sample rate and transforms the sample type to u8