Device

Struct Device 

pub struct Device { /* private fields */ }
An abstraction over cpal::Device, represents a physical output device

Implementations

Source

impl Device

pub fn play_default_output( player: &mut impl SamplesPlayerTrait, ) -> Result<(), PlayError>

Plays the samples on the default device of the default host

pub fn create_stream<T: Sample>( &self, metadata: &impl AudioMetadataTrait, samples: Arc<Mutex<Samples<T>>>, ) -> Result<Stream, PlayError>

Creates a stream that will play the metadata based on the metadata given

pub fn play<T: Sample>( self, player: &mut impl SamplesPlayerTrait, ) -> Result<(), PlayError>

Plays the samples in the SamplesPlayer on this device

pub fn default_output() -> Option<Device>

Returns the default output device of the default host. Be aware that there may be none

pub fn list_device_names() -> Vec<String>

Gives the name of all devices on all hosts

pub fn new_from_name(device_name: &str) -> Option<Device>

Creates a new device from its device name

Source

impl Device

pub fn name(&self) -> Option<String>

Returns the name of the device, if it can find one