pub enum PlayError {
TimeOutOfBounds,
FileNotAccessible(Error),
WrongFileType,
DeviceIoError(String, Option<Box<dyn Error + 'static>>),
DeviceDoesNotSupportAudioSettings(Vec<AudioSettings>, Option<Box<dyn Error + 'static>>),
DeviceDoesNotExist {
name: String,
},
StreamIoError(String, Option<Box<dyn Error + 'static>>),
PoisonedMutex(String, Box<dyn Error>),
Unsupported(String),
}Expand description
The error type used allthrought the ez_audi crate
Variants
TimeOutOfBounds
The time specified is out of bound
FileNotAccessible(Error)
The file is not accesible/does not exist
WrongFileType
The file type hints at the fact that the file type is not the right one
DeviceIoError(String, Option<Box<dyn Error + 'static>>)
Error while trying to communicate with the device
DeviceDoesNotSupportAudioSettings(Vec<AudioSettings>, Option<Box<dyn Error + 'static>>)
The device does not support specific requirements to play the samples
DeviceDoesNotExist
The device does not exist
StreamIoError(String, Option<Box<dyn Error + 'static>>)
Error while trying to comunicate with a stream
PoisonedMutex(String, Box<dyn Error>)
A Mutex got poisoned and is not accessible anymore
Unsupported(String)
Feature is not support as of yet