pub struct Samples<T: Sample> {
pub samples: Vec<T>,
pub metadata: SamplesMetadata,
}Expand description
A sample container of LPcm samples ready to be send to audio streams
Fields
samples: Vec<T>A an ordered vector of all the samples, if there are multiple channels, each channel will have their own sample
ex: 1 channel: [s1, s2, s3]
2 channels: [s-left1, s-right1, s-left-2, s-right-2, s-left-3, s-right-3]
metadata: SamplesMetadataThe metadata of the Samples, dictates how they are consumed and modified. There is no guarenty that the metadata reflects the actual intended metadata.
Implementations
Sourceimpl Samples<IntermediateSampleType>
impl Samples<IntermediateSampleType>
Sourcepub fn into_t_samples<T: Sample + FromSample<IntermediateSampleType>>(
self,
) -> Samples<T>
pub fn into_t_samples<T: Sample + FromSample<IntermediateSampleType>>( self, ) -> Samples<T>
Turns the samples into the desired sample type, does not clone